@@ -5,6 +5,7 @@ from .FCN import *
 from .FCNPlus import *
 from .InceptionTime import *
 from .InceptionTimePlus import *
+from .MLP import *
 from .mWDN import *
 from .OmniScaleCNN import *
 from .ResCNN import *
@@ -17,10 +18,11 @@ from .RNN_FCNPlus import *
 from .ROCKET import *
 from .TransformerModel import *
 from .TST import *
+from .TSTPlus import *
 from .XceptionTime import *
 from .XceptionTimePlus import *
 from .XResNet1d import *
 from .XResNet1dPlus import *
 from fastai.vision.models.xresnet import *
 from .TabModel import *
-from .Hybrid import *
\ No newline at end of file
+from .HybridDL import *
\ No newline at end of file
